@@ -1,7 +1,7 @@
 package Sah::Schema::negfloat;
 
-our $DATE = '2020-03-04'; # DATE
-our $VERSION = '0.007'; # VERSION
+our $DATE = '2020-03-08'; # DATE
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [float => {
     summary   => 'Negative float',
@@ -32,7 +32,7 @@ Sah::Schema::negfloat - Negative float
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::negfloat (from Perl distribution Sah-Schemas-Float), released on 2020-03-04.
+This document describes version 0.008 of Sah::Schema::negfloat (from Perl distribution Sah-Schemas-Float), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -46,7 +46,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -68,13 +68,13 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ 0  # INVALID
 
- undef  # INVALID
+ 0.1  # INVALID
 
- undef  # valid
+ -0.1  # valid
 
- undef  # valid
+ -1  # valid
 
 =head1 HOMEPAGE
 
