@@ -1,9 +1,9 @@
 package Sah::Schema::share;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Float'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = ['float', {
     summary => 'A float between 0 and 1',
@@ -49,7 +49,7 @@ Sah::Schema::share - A float between 0 and 1
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::share (from Perl distribution Sah-Schemas-Float), released on 2020-03-04.
+This document describes version 0.008 of Sah::Schema::share (from Perl distribution Sah-Schemas-Float), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -63,7 +63,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -85,17 +85,17 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ 0  # valid, becomes 0
 
- undef  # valid
+ 0.5  # valid, becomes 0.5
 
- undef  # valid
+ 1  # valid, becomes 1
 
- undef  # valid
+ 1.2  # valid, becomes 0.012
 
- undef  # valid
+ "1.2%"  # valid, becomes 0.012
 
- undef  # INVALID
+ "102%"  # INVALID
 
 =head1 DESCRIPTION
 
