@@ -1,9 +1,9 @@
 package Sah::Schema::ufloat;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Float'; # DIST
-our $VERSION = '0.007'; # VERSION
+our $VERSION = '0.008'; # VERSION
 
 our $schema = [float => {
     summary   => 'Non-negative float',
@@ -37,7 +37,7 @@ Sah::Schema::ufloat - Non-negative float
 
 =head1 VERSION
 
-This document describes version 0.007 of Sah::Schema::ufloat (from Perl distribution Sah-Schemas-Float), released on 2020-03-04.
+This document describes version 0.008 of Sah::Schema::ufloat (from Perl distribution Sah-Schemas-Float), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -51,7 +51,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -73,13 +73,13 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # valid
+ 0  # valid
 
- undef  # valid
+ 0.1  # valid
 
- undef  # valid
+ 1  # valid
 
- undef  # INVALID
+ -0.1  # INVALID
 
 =head1 DESCRIPTION
 
